@@ -18,8 +18,8 @@ fn successful_execution() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/true"
-            &base64_decode("L2Jpbi90cnVl"),
+            // "true"
+            &base64_decode("dHJ1ZQ=="),
         )
         .args(
             // ""
@@ -62,8 +62,8 @@ fn successful_execution_in_a_sub_directory() {
             &base64_decode("eHl6enk="),
         )
         .argv0(
-            // "/bin/pwd"
-            &base64_decode("L2Jpbi9wd2Q="),
+            // "pwd"
+            &base64_decode("cHdk"),
         )
         .args(
             // ""
@@ -100,8 +100,8 @@ fn failed_execution() {
 
     let step = subplotlib::steplibrary::runcmd::try_to_run::Builder::default()
         .argv0(
-            // "/bin/false"
-            &base64_decode("L2Jpbi9mYWxzZQ=="),
+            // "false"
+            &base64_decode("ZmFsc2U="),
         )
         .args(
             // ""
@@ -144,8 +144,8 @@ fn failed_execution_in_a_sub_directory() {
             &base64_decode("eHl6enk="),
         )
         .argv0(
-            // "/bin/false"
-            &base64_decode("L2Jpbi9mYWxzZQ=="),
+            // "false"
+            &base64_decode("ZmFsc2U="),
         )
         .args(
             // ""
@@ -176,8 +176,8 @@ fn check_stdout_is_exactly_as_wanted() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hello, world"
@@ -254,8 +254,8 @@ fn check_stdout_using_sub_string_search() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hello, world"
@@ -337,8 +337,8 @@ fn check_stdout_using_regular_expressions() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hello, world"
@@ -415,8 +415,8 @@ fn check_stdout_is_not_exactly_something() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hi"
@@ -493,8 +493,8 @@ fn check_stdout_doesn_t_contain_sub_string() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hi"
@@ -571,8 +571,8 @@ fn check_stdout_doesn_t_match_regular_expression() {
 
     let step = subplotlib::steplibrary::runcmd::run::Builder::default()
         .argv0(
-            // "/bin/echo"
-            &base64_decode("L2Jpbi9lY2hv"),
+            // "echo"
+            &base64_decode("ZWNobw=="),
         )
         .args(
             // " hi"
